@@ -5,22 +5,19 @@ from typing import Optional
 
 from django.db import models
 from django.utils.translation import gettext_lazy as _
-from wagtail.admin.edit_handlers import (
+from wagtail.admin.panels import (
     HelpPanel,
     FieldPanel,
     MultiFieldPanel,
-    StreamFieldPanel,
 )
 from wagtail.contrib.settings.models import BaseSetting, register_setting
-from wagtail.core.fields import StreamField
-from wagtail.core.models import Page
+from wagtail.fields import StreamField
+from wagtail.models import Page
 from wagtail.images import get_image_model_string
-from wagtail.images.edit_handlers import ImageChooserPanel
 from wagtail.images.models import AbstractImage
 
 from wagtailseo import settings, schema, utils
 from wagtailseo.blocks import OpenHoursBlock, StructuredDataActionBlock
-from wagtailseo.icon import SEO_ICON
 
 
 class SeoType(Enum):
@@ -140,14 +137,14 @@ class SeoMixin(Page):
     struct_org_geo_lat = models.DecimalField(
         blank=True,
         null=True,
-        max_digits=10,
+        max_digits=11,
         decimal_places=8,
         verbose_name=_("Geographic latitude"),
     )
     struct_org_geo_lng = models.DecimalField(
         blank=True,
         null=True,
-        max_digits=10,
+        max_digits=11,
         decimal_places=8,
         verbose_name=_("Geographic longitude"),
     )
@@ -155,11 +152,13 @@ class SeoMixin(Page):
         [("hours", OpenHoursBlock())],
         blank=True,
         verbose_name=_("Hours of operation"),
+        use_json_field=True,
     )
     struct_org_actions = StreamField(
         [("actions", StructuredDataActionBlock())],
         blank=True,
         verbose_name=_("Actions"),
+        use_json_field=True,
     )
     struct_org_extra_json = models.TextField(
         blank=True,
@@ -201,13 +200,6 @@ class SeoMixin(Page):
     # The style of Twitter card to show.
     seo_twitter_card = TwitterCard.SUMMARY
 
-    @property
-    def seo_amp_url(self) -> str:
-        """
-        Gets the full/absolute/canonical URL for the AMP version of this page.
-        """
-        return "{0}?amp".format(self.seo_canonical_url)
-
     @property
     def seo_author(self) -> str:
         """
@@ -301,7 +293,10 @@ class SeoMixin(Page):
         Gets the site name.
         Override in your Page model as necessary.
         """
-        return self.get_site().site_name
+        s = self.get_site()
+        if s:
+            return s.site_name
+        return ""
 
     @property
     def seo_pagetitle(self) -> str:
@@ -511,7 +506,7 @@ class SeoMixin(Page):
                 FieldPanel("seo_title"),
                 FieldPanel("search_description"),
                 FieldPanel("canonical_url"),
-                ImageChooserPanel("og_image"),
+                FieldPanel("og_image"),
             ],
             _("Search and Social Previews"),
         ),
@@ -535,8 +530,8 @@ class SeoMixin(Page):
                 ),
                 FieldPanel("struct_org_type"),
                 FieldPanel("struct_org_name"),
-                ImageChooserPanel("struct_org_logo"),
-                ImageChooserPanel("struct_org_image"),
+                FieldPanel("struct_org_logo"),
+                FieldPanel("struct_org_image"),
                 FieldPanel("struct_org_phone"),
                 FieldPanel("struct_org_address_street"),
                 FieldPanel("struct_org_address_locality"),
@@ -545,8 +540,8 @@ class SeoMixin(Page):
                 FieldPanel("struct_org_address_country"),
                 FieldPanel("struct_org_geo_lat"),
                 FieldPanel("struct_org_geo_lng"),
-                StreamFieldPanel("struct_org_hours"),
-                StreamFieldPanel("struct_org_actions"),
+                FieldPanel("struct_org_hours"),
+                FieldPanel("struct_org_actions"),
                 FieldPanel("struct_org_extra_json"),
             ],
             _("Structured Data - Organization"),
@@ -556,7 +551,7 @@ class SeoMixin(Page):
     seo_panels = seo_meta_panels + seo_menu_panels + seo_struct_panels
 
 
-@register_setting(icon=SEO_ICON)
+@register_setting(icon="wagtailseo-line-chart")
 class SeoSettings(BaseSetting):
     """
     Toggle Search engine optimization features and meta tags.
@@ -595,14 +590,6 @@ class SeoSettings(BaseSetting):
             "See https://schema.org/"
         ),
     )
-    amp_pages = models.BooleanField(
-        default=True,
-        verbose_name=_("Use AMP Pages"),
-        help_text=_(
-            "Generates an alternate AMP version of article pages that are "
-            "preferred by search engines. See https://amp.dev/"
-        ),
-    )
 
     @property
     def at_twitter_site(self):
@@ -615,7 +602,6 @@ class SeoSettings(BaseSetting):
     panels = [
         MultiFieldPanel(
             [
-                FieldPanel("amp_pages"),
                 FieldPanel("og_meta"),
                 FieldPanel("struct_meta"),
                 FieldPanel("twitter_meta"),
